@@ -3,10 +3,12 @@ from __future__ import absolute_import, unicode_literals, division
 from ._version import __version__, __version_info__  # noqa
 from .decorators import route, resource, asynchronous
 from .helpers import use
+from .relationship import Relationship
 
 __all__ = [
     'route',
     'resource',
     'asynchronous',
-    'use'
+    'use',
+    'Relationship'
 ]
