@@ -4,6 +4,7 @@ import six
 import operator
 from functools import partial
 from collections import Iterable
+from urllib.parse import unquote_plus
 from copy import deepcopy
 from six.moves import map, reduce
 from armet.exceptions import ImproperlyConfigured
@@ -32,7 +33,7 @@ def ilike_helper(default):
     def wrapped(x, y):
         # String values should use ILIKE queries.
         if isinstance(y, six.string_types) and not isinstance(x.type, sa.Enum):
-            return x.ilike("%" + y + "%")
+            return x.ilike(unquote_plus("%" + y + "%"))
         else:
             return default(x, y)
     return wrapped
